@@ -19,15 +19,14 @@ use FSA::Rules;
 use Siebel::Srvrmgr::ListParser::OutputFactory;
 use Siebel::Srvrmgr::ListParser::Buffer;
 use Siebel::Srvrmgr::Regexes qw(SRVRMGR_PROMPT CONN_GREET);
-use Scalar::Util qw(weaken);
 
 =pod
 
 =head1 DESCRIPTION
 
-Siebel::Srvrmgr::ListParser is a state machine parser created to parse output of "list" commands executed through C<srvrmgr> program.
+Siebel::Srvrmgr::ListParser is a state machine parser created to parse output of "list" commands executed through srvrmgr program.
 
-The parser can identify different types of commands and their outputs from a buffer given as parameter to the module. For each 
+The parser can idenfity different types of commands and their outputs from a buffer given as parameter to the module. Foreach 
 type of output identified an L<Siebel::Srvrmgr::ListParser::Buffer> object will be created, identifying which type of command
 was executed and the raw information from it.
 
@@ -36,7 +35,7 @@ specific L<Siebel::Srvrmgr::ListParser::Output> objects based on the identified
 parse the raw output and populate attributes based on this information. After this is easier to obtain the information from
 those subclasses of L<Siebel::Srvrmgr::ListParser::Output>.
 
-Siebel::Srvrmgr::ListParser expects to receive output from C<srvrmgr> program in an specific format and is able to idenfity a
+Siebel::Srvrmgr::ListParser expects to receive output from srvrmgr program in an specific format and is able to idenfity a
 limited number of commands and their outputs, raising an exception when those types cannot be identified. See subclasses
 of L<Siebel::Srvrmgr::ListParser::Output> to see which classes/types are available.
 
@@ -73,9 +72,7 @@ has 'has_tree' =>
 
 =head2 prompt_regex
 
-A regular expression reference of how the C<srvrmgr> prompt looks like.
-
-By default this regular expression value is defined by L<Siebel::Srvrmgr::Regexes>::SRVRMGR_PROMPT.
+A regular expression reference of how the srvrmgr prompt looks like.
 
 =cut
 
@@ -94,8 +91,6 @@ has 'prompt_regex' => (
 A regular expression reference of how the first line of text received right after the login in one
 server (or enterprise).
 
-By default this regular expression value is defined by L<Siebel::Srvrmgr::Regexes>::CON_GREET.
-
 =cut
 
 has 'hello_regex' => (
@@ -152,6 +147,16 @@ has 'buffer' => (
 
 =pod
 
+=head2 is_warn_enabled
+
+A boolean value that is used for debugging purpouses during the parsing time. If enabled some debug messages may be printed during this phase.
+
+=cut
+
+has 'is_warn_enabled' => ( isa => 'Bool', is => 'ro', default => 0 );
+
+=pod
+
 =head1 METHODS
 
 =head2 is_cmd_changed
@@ -404,9 +409,9 @@ sub append_output {
 
 Parses one or more commands output executed through C<srvrmgr> program.
 
-Expects as parameter an array reference with the output of C<srvrmgr>, including the command executed.
+Expects as parameter an array reference with the output of srvrmgr, including the command executed.
 
-It will create an L<FSA::Rules> object to parse the given array reference, calling C<append_output> method for each L<Siebel::Srvrmgr::ListParser::Buffer> object
+It will create an C<FSA::Rules> object to parse the given array reference, calling C<append_output> method for each C<Siebel::Srvrmgr::ListParser::Buffer> object
 found.
 
 This method will raise an exception if a given output cannot be identified by the parser.
@@ -423,15 +428,22 @@ sub parse {
     die "data parameter must be an array reference\n"
       unless ( ref($data_ref) eq 'ARRAY' );
 
-    warn "received an empty buffer" unless ( @{$data_ref} );
-
+# :TODO:27/2/2012 15:06:20:: treat STDOUT messages adding a "warn" to notes method based on is_warn_enabled attribute
     my $fsa = FSA::Rules->new(
-        no_data => {
+        first_line => {
             do => sub {
-                print "Searching for useful data\n"
-                  if ( $ENV{SIEBEL_SRVRMGR_DEBUG} );
+                print "Searching for useful data\n";
             },
             rules => [
+                command_submission => sub {
+
+                    my $state = shift;
+                    my $line  = $state->notes('line');
+
+                    return ( $state->notes('line') =~
+                          $state->notes('parser')->get_prompt_regex() );
+
+                },
                 greetings => sub {
 
                     my $state = shift;
@@ -440,15 +452,7 @@ sub parse {
                           $state->notes('parser')->get_hello_regex() );
 
                 },
-                command_submission => sub {
-
-                    my $state = shift;
-
-                    return ( $state->notes('line') =~
-                          $state->notes('parser')->get_prompt_regex() );
-
-                },
-                no_data => sub { return 1 }
+                first_line => sub { return 1 }
             ],
             message => 'Line read'
 
@@ -479,7 +483,7 @@ sub parse {
         end => {
             do    => sub { print "Enterprise says 'bye-bye'\n"; },
             rules => [
-                no_data => sub {
+                first_line => sub {
                     return 1;
                   }
             ],
@@ -581,54 +585,6 @@ sub parse {
             ],
             message => 'prompt found'
         },
-        list_tasks => {
-            do => sub {
-                my $state = shift;
-
-                $state->notes('parser')->set_buffer($state);
-
-            },
-            on_exit => sub {
-                my $state = shift;
-                $state->notes('parser')->is_cmd_changed(0);
-            },
-            rules => [
-                command_submission => sub {
-
-                    my $state = shift;
-
-                    return ( $state->notes('line') =~
-                          $state->notes('parser')->get_prompt_regex() );
-
-                },
-                list_tasks => sub { return 1; }
-            ],
-            message => 'prompt found'
-        },
-        list_servers => {
-            do => sub {
-                my $state = shift;
-
-                $state->notes('parser')->set_buffer($state);
-
-            },
-            on_exit => sub {
-                my $state = shift;
-                $state->notes('parser')->is_cmd_changed(0);
-            },
-            rules => [
-                command_submission => sub {
-
-                    my $state = shift;
-
-                    return ( $state->notes('line') =~
-                          $state->notes('parser')->get_prompt_regex() );
-
-                },
-                list_servers => sub { return 1; }
-            ],
-            message => 'prompt found'
-        },
         load_preferences => {
             do => sub {
                 my $state = shift;
@@ -658,18 +614,11 @@ sub parse {
 
                 my $state = shift;
 
-                if ( $ENV{SIEBEL_SRVRMGR_DEBUG} ) {
-
-                    my $line = $state->notes('line');
-                    print "command_submission got [$line]\n";
-
-                }
-
                 my $cmd =
                   ( $state->notes('line') =~
                       $state->notes('parser')->get_prompt_regex() )[1];
 
-                if ( ( defined($cmd) ) and ( $cmd ne '' ) ) {
+                if ( defined($cmd) ) {
 
                     # removing spaces from command
                     $cmd =~ s/^\s+//;
@@ -679,12 +628,11 @@ sub parse {
                 }
                 else {
 
-                    if ( $ENV{SIEBEL_SRVRMGR_DEBUG} ) {
+                    if ( $state->notes('parser')->is_warn_enabled() ) {
 
                         warn 'got prompt, but no command submitted in line '
-                          . $state->notes('line_num') . "\n";
-
-                        $state->notes('parser')->set_last_command('');
+                          . $state->notes('line_num') . "\n"
+                          unless ( defined($cmd) );
 
                     }
 
@@ -753,45 +701,6 @@ sub parse {
 
                     }
 
-                },
-                list_tasks => sub {
-
-                    my $state = shift;
-
-           # :TODO:20/12/2011 18:05:33:: replace the regex for a precompiled one
-                    if ( $state->notes('parser')->get_last_command() =~
-/list\stasks(\sfor\sserver\s\w+\scomponent\sgroup?\s\w+)?/
-                      )
-                    {
-
-                        return 1;
-
-                    }
-                    else {
-
-                        return 0;
-
-                    }
-
-                },
-                list_servers => sub {
-
-                    my $state = shift;
-
-           # :TODO:20/12/2011 18:05:33:: replace the regex for a precompiled one
-                    if ( $state->notes('parser')->get_last_command() =~
-                        /list\sserver(s)?.*/ )
-                    {
-
-                        return 1;
-
-                    }
-                    else {
-
-                        return 0;
-
-                    }
-
                 },
                 list_comp_def => sub {
 
@@ -830,27 +739,8 @@ sub parse {
                     }
 
                 },
-                no_data => sub {
-
-                    my $state = shift;
-
-                    if ( $state->notes('parser')->get_last_command() eq '' ) {
-
-                        return 1;
-
-                    }
-                    else {
-
-                        return 0;
-
-                    }
-
-                },
 
      # :TODO:06/07/2011 13:38:58:: add other possibilities here of list commands
-                command_submission =>
-                  sub { return 1; }    # this must be the last item
-
             ],
             message => 'command submitted'
         }
@@ -870,8 +760,6 @@ sub parse {
 # :TODO:07/07/2011 14:56:04:: this should be changed to avoid circular references
             $state->notes( parser => $self );
 
-            #            weaken( $state->notes('parser') );
-
         }
 
         $line =~ s/\n$//;
@@ -899,12 +787,12 @@ sub parse {
 
 =head1 CAVEATS
 
-Checkout the POD for the L<Siebel::Srvrmgr::ListParser::Output> objects to see details about which kind of output is expected if you're getting errors from the parser. There 
+Checkout the POD for the C<Siebel::Srvrmgr::ListParser::Output> objects to see details about which kind of output is expected if you're getting errors from the parser. There 
 are details regarding how the settings of srvrmgr are expect for output of list commands.
 
 =head1 SEE ALSO
 
-=over 6 
+=over 4 
 
 =item *
 
@@ -916,47 +804,15 @@ L<FSA::Rules>
 
 =item *
 
-L<Siebel::Srvrmgr::ListParser::Output>
-
-=item *
-
 L<Siebel::Srvrmgr::ListParser::OutputFactory>
 
 =item *
 
 L<Siebel::Srvrmgr::ListParser::Buffer>
 
-=item *
-
-L<Siebel::Srvrmgr::Regexes>
-
 =back
 
-=head1 AUTHOR
-
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
-
-This file is part of Siebel Monitoring Tools.
-
-Siebel Monitoring Tools is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Siebel Monitoring Tools is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
-
 =cut
 
+no Moose;
 __PACKAGE__->meta->make_immutable;
-
-1;
