@@ -4,7 +4,7 @@ package Siebel::Srvrmgr::ListParser::Output::ListComp;
 
 =head1 NAME
 
-Siebel::Srvrmgr::ListParser::Output::Listcomp - subclass that parses list comp commands output of srvrmgr.
+Siebel::Srvrmgr::ListParser::Output::Listcomp - subclass that parses C<list comp> commands output of srvrmgr.
 
 =cut
 
@@ -38,7 +38,7 @@ can see below:
 		CC_ALIAS (31):  Component alias
 		CC_NAME (76):  Component name
 		CT_ALIAS (31):  Component type alias
-		CG_ALIAS (31):  Component Group Alias
+		CG_ALIAS (31):  Component GRoup Alias
 		CC_RUNMODE (31):  Component run mode (enum)
 		CP_DISP_RUN_STATE (61):  Component display run state
 		CP_NUM_RUN_TASKS (11):  Current number of running tasks
@@ -51,12 +51,12 @@ can see below:
 		CC_INCARN_NO (23):  Incarnation Number
 		CC_DESC_TEXT (251):  Component description
 
-This output above should be the default but it will be necessary to have the configuration below
+This should be the default configuration, but it will be necessary to have the configuration below
 (check the difference of size for each column):
 
 	srvrmgr> configure list comp
 		SV_NAME (31):  Server name
-		CC_ALIAS (31):  Component alias
+		CC_ALIAS (21):  Component alias
 		CC_NAME (76):  Component name
 		CT_ALIAS (31):  Component type alias
 		CG_ALIAS (31):  Component GRoup Alias
@@ -76,13 +76,13 @@ because L<Siebel::Srvrmgr::ListParser::Output::ListComp::Comp> will expect to ha
 truncated. This class will check those columns names and order and it will raise an exception if it found something different
 from the expected.
 
-To enable that, execute the following commands in the C<srvrmgr> program:
+To enable that, execute the following commands in the srvrmgr program:
 
 	set ColumnWidth true
-    
-	configure list components show SV_NAME(31), CC_ALIAS(31), CC_NAME(76), CT_ALIAS(31), CG_ALIAS(31), CC_RUNMODE(31), CP_DISP_RUN_STATE(61),\
-	CP_NUM_RUN_TASKS(16), CP_MAX_TASKS(12), CP_ACTV_MTS_PROCS(17), CP_MAX_MTS_PROCS(16), CP_START_TIME(21), CP_END_TIME(21),\
-	CP_STATUS(251), CC_INCARN_NO(23), CC_DESC_TEXT(251)
+
+	configure list comp show SV_NAME(31), CC_ALIAS(21), CC_NAME(31), CG_ALIAS(31), CC_RUNMODE(31), CP_DISP_RUN_STATE(61),\
+	CP_NUM_RUN_TASKS(16), CP_MAX_TASKS(11), CP_ACTV_MTS_PROCS(17), CP_MAX_MTS_PROCS(16), CP_START_TIME(21), \
+	CP_END_TIME(21), CP_STATUS(251), CC_INCARN_NO(23), CC_DESC_TEXT(251)
 
 Saving this configuration as a preference and loading it everytime is a good idea too.
 
@@ -232,93 +232,139 @@ sub _set_last_server {
 
 }
 
-sub _set_header_regex {
-
-    return qr/^SV_NAME\s+CC_ALIAS/;
-
-}
-
 =pod
 
-=head2 _set_header
+=head2 parse
 
-_set_header method is overrided to also set the C<comp_attribs> attribute. The parent class method is also invoked (prior to setting C<comp_attribs>).
+Parsers the data available in the C<raw_data> attribute, populating the C<data_parsed> attribute.
+
+The C<raw_data> attribute will be set to an empty array reference once the parsing is finished.
 
 =cut
 
-override '_set_header' => sub {
+sub parse {
 
     my $self = shift;
-    my $line = shift;
 
-    # defines header_cols
-    super();
+    my $data_ref = $self->get_raw_data();
 
-    my $columns_ref = $self->get_header_cols();
+    my %parsed_lines;
 
-    #SV_NAME is useless here
-    shift( @{$columns_ref} );
+    # removing the three last lines Siebel 7.5.3
+    for ( 1 .. 3 ) {
 
-    # component alias do not need to be maintained here
-    shift( @{$columns_ref} );
-
-    $self->_set_comp_attribs($columns_ref);
-
-    return 1;
-
-};
-
-sub _parse_data {
-
-    my $self       = shift;
-    my $fields_ref = shift;
-    my $parsed_ref = shift;
-
-    confess 'invalid fields parameter'
-      unless ( ( defined($fields_ref) )
-        and ( ( ref($fields_ref) ) eq 'ARRAY' )
-        and ( ( scalar( @{$fields_ref} ) ) > 0 ) );
-
-    my $server = shift( @{$fields_ref} );
-
-    # do not need the servername again
-    if (   ( $self->get_last_server() eq '' )
-        or ( $self->get_last_server() ne $server ) )
-    {
-
-        $self->_set_last_server($server);
+        pop( @{$data_ref} );
 
     }
 
-    my $comp_alias = shift( @{$fields_ref} );
+    foreach my $line ( @{$data_ref} ) {
 
-    my $list_len = scalar( @{$fields_ref} );
+        chomp($line);
 
-# :TODO      :08/05/2013 18:19:48:: replace comp_attribs with header_cols? seems to be the same thing
-    my $columns_ref = $self->get_comp_attribs();
+      SWITCH: {
 
-    confess "Cannot continue without defining fields names"
-      unless ( defined($columns_ref) );
+            if ( $line =~ /^\-+\s/ ) {
 
-    if ( @{$fields_ref} ) {
+                my @columns = split( /\s{2}/, $line );
 
-        for ( my $i = 0 ; $i < $list_len ; $i++ ) {
+                my $pattern;
 
-            my $server = $self->get_last_server();
+                foreach my $column (@columns) {
 
-            $parsed_ref->{$server}->{$comp_alias}->{ $columns_ref->[$i] } =
-              $fields_ref->[$i];
+                    $pattern .= 'A'
+                      . ( length($column) + 2 )
+                      ; # + 2 because of the spaces after the "---" that will be trimmed
+
+                }
+
+                $self->_set_fields_pattern($pattern);
+
+                last SWITCH;
+
+            }
+
+            if ( $line eq '' ) {
+
+                last SWITCH;
+
+            }
+
+            #SV_NAME     CC_ALIAS
+            if ( $line =~ /^SV_NAME\s+CC_ALIAS/ ) {
+
+                my @columns = split( /\s{2,}/, $line );
+
+                #SV_NAME is usuless here
+                shift(@columns);
+
+                # component alias do not need to be maintained here
+                shift(@columns);
+
+                $self->_set_comp_attribs( \@columns );
+
+                last SWITCH;
+
+            }
+            else {
+
+                my @fields_values;
+
+                if ( $self->get_fields_pattern() ) {
+
+                    @fields_values =
+                      unpack( $self->get_fields_pattern(), $line );
+
+                }
+                else {
+
+                    die
+                      "Cannot continue since fields pattern was not defined\n";
+
+                }
+
+                my $server = shift(@fields_values);
+
+                # do not need the servername again
+                if (   ( $self->get_last_server() eq '' )
+                    or ( $self->get_last_server() ne $server ) )
+                {
+
+                    $self->_set_last_server($server);
+
+                }
+
+                my $comp_alias = shift(@fields_values);
+
+                my $list_len = scalar(@fields_values);
+
+                my $columns_ref = $self->get_comp_attribs();
+
+                if (@fields_values) {
+
+                    for ( my $i = 0 ; $i < $list_len ; $i++ ) {
+
+                        my $server = $self->get_last_server();
+
+                        $parsed_lines{$server}->{$comp_alias}
+                          ->{ $columns_ref->[$i] } = $fields_values[$i];
+
+                    }
+
+                }
+                else {
+
+                    warn "got nothing\n";
+
+                }
+
+            }
 
         }
 
-        return 1;
-
     }
-    else {
 
-        return 0;
-
-    }
+    $self->set_data_parsed( \%parsed_lines );
+    $self->set_raw_data( [] );
 
 }
 
@@ -346,28 +392,6 @@ L<Siebel::Srvrmgr::ListParser::Output::ListComp::Comp>
 
 =back
 
-=head1 AUTHOR
-
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
-
-This file is part of Siebel Monitoring Tools.
-
-Siebel Monitoring Tools is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Siebel Monitoring Tools is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
